#
# spec file for package quakespasm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Luke Jones <luke.nukem.jones@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           quakespasm
Version:        0.93.2
Release:        bp153.1.14
Summary:        A Quake Engine
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
Url:            http://quakespasm.sourceforge.net/
Source:         http://ufpr.dl.sourceforge.net/project/quakespasm/Source/%{name}-%{version}.tgz
Source100:      quakespasm.appdata.xml
Source99:       %{name}.changes
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(vorbis)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
QuakeSpasm is a Quake 1 engine based on the SDL2 port of FitzQuake.  It includes
64-bit CPU support, a new sound driver, several networking fixes and a few
graphical niceities, while also staying true to the original game.
Game data must be placed in ~/.quakespasm/id1 .

%prep
%setup
# Fix usage of __DATE__ and __TIME__ macros to prevent build in excess
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" Quake/host.c
# Prepare for later installation
mkdir html/
ln -s README.html ./html/README.html
mv Quakespasm.txt README
mv Quakespasm-Music.txt MUSIC
mv LICENSE.txt LICENSE

%build
export CFLAGS='%{optflags} -DQUAKE_BASEDIR=\"%{_datadir}/quake\"'
make %{?_smp_mflags} -C Quake\
    DO_USERDIRS=1 \
    USE_CODEC_MP3=0 \
    USE_SDL2=1

%install
install -D -p -m 755 Quake/quakespasm %{buildroot}%{_bindir}/quakespasm
install -D -p -m 644 Misc/QuakeSpasm_512.png %{buildroot}%{_datadir}/pixmaps/quakespasm.png
install -D -p -m 644 %{SOURCE100}  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -d -m 755 %{buildroot}%{_datadir}/quake/

%suse_update_desktop_file -c %{name} 'Quake' 'QuakeSpasm' %{name} %{name} Game ActionGame

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc README MUSIC LICENSE html/
%{_bindir}/%{name}
%dir %{_datadir}/quake/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%if ( 0%{?suse_version} == 1315 && 0%{?sle_version} == 120100 ) || ! 0%{?is_opensuse}
# Leap 42.1 or SLE
%dir %{_datadir}/appdata
%endif
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Thu Nov 14 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.93.2
  * Lightmaps are now dynamically allocated (from QSS), and
    BLOCK_WIDTH/HEIGHT raised from 128 to 256.
  * Fixed several uncheked limits that would crash the Slayer's
    Testaments mod
  * Raised MAXALIASTRIS from 2048 to 4096, so that the Slayer's
    Testaments mod works.
  * Fixed 'pants' and 'shirt' types so that those textures load
    correctly on platforms where char is unsigned by default
  • Update the third-party libraries. Other fixes/cleanups.
* Sun Aug  5 2018 mardnh@gmx.de
- Update to version 0.93.1
  * Fixed a fog regression which was introduced in 0.93.0.
  * Fixed a crash (buffer overflow) with invalid vis data.
  * Fixed buttons crushing players in 64-bit builds.
  * Change controller movement to use cubic easing by default; added
    "joy_exponent_move" cvar.
  * config.cfg is no longer written in case of a Sys_Error.
  * Fixed Opus encoded cd tracks not being recognized as ripped tracks.
  * Update the third-party libraries. Other fixes/cleanups.
- Update to version 0.93.0
  * Raise default "joy_deadzone_trigger" cvar to 0.2.
  * Raise console buffer size to 1MB.
  * Raise MAX_STATIC_ENTITIES from 512 to 4096.
  * Raise MAX_STACK_DEPTH from 32 to 64.
  * Raise command buffer size from 8K to 256K to support large configs.
  * Remove MAX_EFRAGS and MAX_MAP_LEAFS limits.
  * Remove "Loadgame buffer overflow" limit, which could happen when
    loading DP or QSS saves.
  * Adjust "exceeds standard limit of" debug warnings to include the
    actual QS limit.
  * Change "game" command to now exec quake.rc.
  * Change "games" / "mods" commands to list all subdirectories.
  * Restore vid_refreshrate from fitzquake-0.85 for SDL2 builds.
  * Alpha-masked model support. (MF_HOLEY: 0x4000).
  * Invalid skin index now draws skin 0 (WinQuake behaviour) instead of
    blue checkerboard.
  * Change default screenshot format to png. The 'screenshot' command
    now supports optional format (tga, png or jpg) and quality (1-100)
    arguments.
  * Revert "always run" changes from 0.85.9 and move the QuakeSpasm
    customizations to a new "cl_alwaysrun" cvar: Set to 1 in order to
    scale forward/side/up speed by "cl_movespeedkey" (usually 2), and
    to make "speedkey" act as "slowkey".
  * Change "always run" menu option to offer three choices:
  - off        (cl_alwaysrun 0, cl_forwardspeed 200, cl_backspeed 200)
  - vanilla    (cl_alwaysrun 0, cl_forwardspeed 400, cl_backspeed 400)
  - quakespasm (cl_alwaysrun 1, cl_forwardspeed 200, cl_backspeed 200)
  * New "r_scale" cvar. Set to 2, 3, or 4 to render the view at 1/2,
    1/3, or 1/4 resolution.
  * New "r_viewmodel_quake" cvar. Set to 1 for WinQuake gun position
    (from MarkV).
  * New "find" / "apropos" command, searches for commands/cvar names
    for the given substring (from Spike).
  * New "randmap" command for loading a random map.
  * New "gl_cshiftpercent_contents", "gl_cshiftpercent_damage",
    "gl_cshiftpercent_bonus", "gl_cshiftpercent_powerup" cvars for
    tuning the strength of specic view blends.
  * GL2 renderer: use a GLSL shader for world faces. Fixes reports of
    integrated+discrete GPU laptops having inconsistent fog rendering.
  * Fix macOS startup delay (avoid calling gethostbyname() for ".local"
    hostnames).
  * Fix memory corruption in PF_lightstyle with out of bounds
    lightstyles.
  * Fix crash in BoundPoly with polygons extending beyond +/-9999.
  * Fix QS window to stay on the current monitor when changing video
    modes (SDL2 only).
  * Fix possible freeze in SV_TouchLinks regardless of what QC does in
    the touch function.
  * Fix for maps with empty strings for vector keys (e.g. "origin");
    don't read uninitialized memory.
  * Support for Open Watcom compiler.
  * Update the third-party libraries.
* Tue Jun 27 2017 luke.nukem.jones@gmail.com
- Fix broken appdata xml
* Fri Feb 24 2017 rpm@fthiessen.de
- Update to 0.92.1
  * Fixed large menu scale factors (was broken in 0.92.0)
  * Fixed PAUSE key (was broken in 0.92.0)
- Fixed build on Leap 42.1 (appdata directory)
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Add appdata.xml
* Sat Jul 30 2016 jengelh@inai.de
- Update License and description field
* Tue Jul 19 2016 rpm@fthiessen.de
- Fixed file-contains-date-and-time rpmlint error.
* Mon Jul 18 2016 luke.nukem.jones@gmail.com
- Update to v0.92.0
* Fri Jul 15 2016 luke.nukem.jones@gmail.com
- Prepare packaging for inclusion in Factory
